@@ -12,9 +12,6 @@ class IsPycharmRun:
             if self.isPycharmRun():
                 print(func.__name__ + " was called")
                 return func(basedir=baseDir, devices=self.deviceUrl, logdir=self.logDir)
-            else:
-                print("非pycharm环境，正常调试模式")
-                return func(basedir=baseDir)
         return wrapped_function
 
     def isPycharmRun(self):
